struct ImageContext {
image_cache: Arc<dyn ImageCache>,
status: Result<(), NetworkError>,
id: PendingImageId,
aborted: bool,
doc: Trusted<Document>,
url: ServoUrl,
element: Trusted<HTMLImageElement>,
}Expand description
The context required for asynchronously loading an external image.
Fields
image_cache: Arc<dyn ImageCache>Reference to the script thread image cache.
status: Result<(), NetworkError>Indicates whether the request failed, and why
id: PendingImageIdThe cache ID for this request.
aborted: boolUsed to mark abort
doc: Trusted<Document>The document associated with this request
url: ServoUrlelement: Trusted<HTMLImageElement>Trait Implementations
Sourceimpl FetchResponseListener for ImageContext
impl FetchResponseListener for ImageContext
Sourcefn should_invoke(&self) -> bool
fn should_invoke(&self) -> bool
A gating mechanism that runs before invoking the listener methods on the target
thread. If the
should_invoke method returns false, the listener does not receive
the notification.fn process_request_body(&mut self, _: RequestId)
fn process_response( &mut self, _: &mut JSContext, request_id: RequestId, metadata: Result<FetchMetadata, NetworkError>, )
fn process_response_chunk( &mut self, _: &mut JSContext, request_id: RequestId, payload: Vec<u8>, )
fn process_response_eof( self, cx: &mut JSContext, request_id: RequestId, response: Result<(), NetworkError>, timing: ResourceFetchTiming, )
fn process_csp_violations( &mut self, _request_id: RequestId, violations: Vec<Violation>, )
Sourceimpl ResourceTimingListener for ImageContext
impl ResourceTimingListener for ImageContext
fn resource_timing_information(&self) -> (InitiatorType, ServoUrl)
fn resource_timing_global(&self) -> DomRoot<GlobalScope>